@@ -1,8 +1,7 @@
 """
 cpymadtools package
 ~~~~~~~~~~~~~~~~~~~
-cpymadtools is a collection of utilities that integrate within my workflow with the `cpymad`
-library.
+cpymadtools is a collection of utilities that integrate within my workflow with the `cpymad` library.
 
 :copyright: (c) 2019 by Felix Soubelet.
 :license: MIT, see LICENSE for more details.
@@ -21,6 +20,13 @@ from .special import (
     apply_lhc_coupling_knob,
     apply_lhc_rigidity_waist_shift_knob,
     deactivate_lhc_arc_sextupoles,
+    get_ips_twiss,
+    get_ir_twiss,
+    install_ac_dipole,
+    make_lhc_beams,
+    make_lhc_thin,
     make_sixtrack_output,
     power_landau_octupoles,
 )
+from .track import track_single_particle
+from .twiss import get_pattern_twiss
